==================================
MerkelDAG implementation in Python
==================================


.. image:: https://img.shields.io/pypi/v/py-ipld-dag.svg
        :target: https://pypi.python.org/pypi/py-ipld-dag

.. image:: https://img.shields.io/travis/ipld/py-ipld-dag.svg
        :target: https://travis-ci.org/ipld/py-ipld-dag

.. image:: https://readthedocs.org/projects/dag/badge/?version=latest
        :target: https://dag.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


MerkelDAG implementation in Python


* Free software: MIT license
* Documentation: https://py-ipld-dag.readthedocs.io.


Features
--------

* TODO
